""" joker package """
import random
from .jokes import joke_list, pun_list


class Joker:
    """Joker class
        joke() -> returns a random joke
        jokes(n) -> returns a list of n jokes
        pun() -> returns a random joke
        puns(n) -> returns a list of n jokes
    """
    def joke(self) -> str:
        """ returns a random joke """
        return random.choice(joke_list)

    def jokes(self, num:int = 10) -> list:
        """ returns a list of n jokes """
        random.shuffle(joke_list)
        return joke_list[0:num]

    def pun(self) -> str:
        """ returns a random pun """
        return random.choice(pun_list)

    def puns(self, num:int = 10) -> list:
        """ returns a list of n puns """
        random.shuffle(pun_list)
        return pun_list[0:num]



""" file for jokes and pun list """

joke_list = [
    "I'm afraid for the calendar. Its days are numbered.",
    "My wife said I should do lunges to stay in shape. That would be a big step forward.",
    "Why do fathers take an extra pair of socks when they go golfing?" "In case they get a hole in one!",
    "Singing in the shower is fun until you get soap in your mouth. Then it's a soap opera.",
    "What do a tick and the Eiffel Tower have in common?" "They're both Paris sites.",
    "What do you call a fish wearing a bowtie?" "Sofishticated.",
    "How do you follow Will Smith in the snow?" "You follow the fresh prints.",
    "If April showers bring May flowers, what do May flowers bring?" "Pilgrims.",
    "I thought the dryer was shrinking my clothes. Turns out it was the refrigerator all along.",
    "What do you call a factory that makes okay products?" "A satisfactory.",
    "Dear Math, grow up and solve your own problems.",
    "What did the janitor say when he jumped out of the closet?" "Supplies!",
    "Have you heard about the chocolate record player? It sounds pretty sweet.",
    "What did the ocean say to the beach?" "Nothing, it just waved.",
    "Why do seagulls fly over the ocean?" "Because if they flew over the bay, we'd call them bagels.",
    "I only know 25 letters of the alphabet. I don't know y.",
    "How does the moon cut his hair?" "Eclipse it.",
    "What did one wall say to the other?" "I'll meet you at the corner.",
    "What did the zero say to the eight?" "That belt looks good on you.",
    "A skeleton walks into a bar and says, 'Hey, bartender. I'll have one beer and a mop.'",
    "Where do fruits go on vacation?" "Pear-is!",
    "I asked my dog what's two minus two. He said nothing.",
    "What did Baby Corn say to Mama Corn?" "Where's Pop Corn?",
    "What's the best thing about Switzerland?" "I don't know, but the flag is a big plus.",
    "What does a sprinter eat before a race?" "Nothing, they fast!",
    "Where do you learn to make a banana split?" "Sundae school.",
    "What has more letters than the alphabet?" "The post office!",
    "Dad, did you get a haircut?" "No, I got them all cut!",
    "What do you call a poor Santa Claus?" "St. Nickel-less.",
    "I got carded at a liquor store, and my Blockbuster card accidentally fell out. The cashier said never mind.",
    "Where do boats go when they're sick?" "To the boat doc.",
    "I don't trust those trees. They seem kind of shady.",
    "My wife is really mad at the fact that I have no sense of direction. So I packed up my stuff and right!",
    "How do you get a squirrel to like you? Act like a nut.",
    "Why don't eggs tell jokes? They'd crack each other up.",
    "I don't trust stairs. They're always up to something.",
    "What do you call someone with no body and no nose? Nobody knows.",
    "Did you hear the rumor about butter? Well, I'm not going to spread it!",
    "Why couldn't the bicycle stand up by itself? It was two tired.",
    "What did one hat say to the other?" "Stay here! I'm going on ahead.",
    "Why did Billy get fired from the banana factory? He kept throwing away the bent ones.",
    "Dad, can you put my shoes on?" "No, I don't think they'll fit me.",
    "Why can't a nose be 12 inches long? Because then it would be a foot.",
    "What does a lemon say when it answers the phone?" "Yellow!",
    "This graveyard looks overcrowded. People must be dying to get in.",
    "What kind of car does an egg drive?" "A yolkswagen.",
    "Dad, can you put the cat out?" "I didn't know it was on fire.",
    "How do you make 7 even?" "Take away the s.",
    "How does a taco say grace?" "Lettuce pray.",
    "What time did the man go to the dentist? Tooth hurt-y.",
    "Why didn't the skeleton climb the mountain?" "It didn't have the guts.",
    "What do you call it when a snowman throws a tantrum?" "A meltdown.",
    "How many tickles does it take to make an octopus laugh? Ten tickles.",
    "I have a joke about chemistry, but I don't think it will get a reaction.",
    "What concert costs just 45 cents? 50 Cent featuring Nickelback!",
    "What does a bee use to brush its hair?" "A honeycomb!",
    "How do you make a tissue dance? You put a little boogie in it.",
    "Why did the math book look so sad? Because of all of its problems!",
    "What do you call cheese that isn't yours? Nacho cheese.",
    "My dad told me a joke about boxing. I guess I missed the punch line.",
    "What kind of shoes do ninjas wear? Sneakers!",
    "How does a penguin build its house? Igloos it together.",
    "How did Harry Potter get down the hill?" "Walking. JK! Rowling.",
]

pun_list = [
    "What country's capital is growing the fastest?" "Ireland. Every day it's Dublin.",
    "I once had a dream I was floating in an ocean of orange soda. It was more of a fanta sea.",
    "Have you ever tried to catch a fog? I tried yesterday but I mist.",
    "Did you hear about the guy who invented the knock-knock joke? He won the 'no-bell' prize.",
    "Did you hear about the silk worm race? It ended in a tie.",
    "Why did Adele cross the road? To say hello from the other side.",
    "What was Forrest Gump’s email password? 1forrest1",
    "Can February March? No, but April May.",
    "Ladies, if he can’t appreciate your fruit jokes, you need to let that mango.",
]
